# Changelog

<!--next-version-placeholder-->

## v1.1.4 (2021-02-26)


## v1.1.3 (2021-02-26)


## v1.1.2 (2021-02-26)


## v1.1.1 (2021-02-26)
### Fix
* query encoding ([`2b12860`](https://github.com/MicaelJarniac/BuildURL/commit/2b128607ed03e96238521d384fc86ba1f2a9e084))

### Documentation
* **readme:** coverage badge ([`aebb516`](https://github.com/MicaelJarniac/BuildURL/commit/aebb51623a1e276b3edc169b2f5d744d3ab0faed))

## v1.1.0 (2021-02-26)
### Feature
* initial commit ([`ff71a91`](https://github.com/MicaelJarniac/BuildURL/commit/ff71a9168cf932b602402b1ee764f27ea3a74517))

### Documentation
* **issue template:** initial commit ([`43e042a`](https://github.com/MicaelJarniac/BuildURL/commit/43e042af060181552e6923dcf86fef8a3e2e5997))
* **readme:** add badges ([`7d64626`](https://github.com/MicaelJarniac/BuildURL/commit/7d6462613b94f8f062bb0a5ab62bf01085af3a83))
* **contributing:** initial commit ([`da8c62b`](https://github.com/MicaelJarniac/BuildURL/commit/da8c62b087811b4fc20aa0a330271926140f9bfa))
